@@ -1,21 +1,8 @@
 /*
- *   Copyright (C) 2015 Ivan Cukic <ivan.cukic(at)kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License version 2,
- *   or (at your option) any later version, as published by the Free
- *   Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2015 Ivan Cukic <ivan.cukic(at)kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "ResultWatcherTest.h"
 
@@ -89,19 +76,19 @@ void ResultWatcherTest::testLinkedResources()
             LinkedResources | Agent::global()
                             | Activity::any());
 
-    watcher.linkToActivity(QUrl("test://link1"), Activity::current());
+    watcher.linkToActivity(QUrl(QStringLiteral("test://link1")), Activity::current());
 
     // A signal should arrive soon, waiting for 5 seconds at most
     CHECK_SIGNAL_RESULT(&watcher, &KAStats::ResultWatcher::resultLinked, 5,
                         (const QString &uri),
-                        QCOMPARE(QString("test://link1"), uri));
+                        QCOMPARE(QStringLiteral("test://link1"), uri));
 
-    watcher.unlinkFromActivity(QUrl("test://link1"), Activity::current());
+    watcher.unlinkFromActivity(QUrl(QStringLiteral("test://link1")), Activity::current());
 
     // A signal should arrive soon, waiting for 5 seconds at most
     CHECK_SIGNAL_RESULT(&watcher, &KAStats::ResultWatcher::resultUnlinked, 5,
                         (const QString &uri),
-                        QCOMPARE(QString("test://link1"), uri));
+                        QCOMPARE(QStringLiteral("test://link1"), uri));
 }
 
 void ResultWatcherTest::testUsedResources()
@@ -116,7 +103,7 @@ void ResultWatcherTest::testUsedResources()
     // Openning a resource for a few seconds
     {
         KActivities::ResourceInstance resource(0);
-        resource.setUri(QUrl("test://test1"));
+        resource.setUri(QUrl(QStringLiteral("test://test1")));
 
         liveSleep(3);
     }
@@ -124,7 +111,7 @@ void ResultWatcherTest::testUsedResources()
     // A signal should arrive soon, waiting for 5 seconds at most
     CHECK_SIGNAL_RESULT(&watcher, &KAStats::ResultWatcher::resultScoreUpdated, 5,
                         (const QString &uri, double),
-                        QCOMPARE(QString("test://test1"), uri));
+                        QCOMPARE(QStringLiteral("test://test1"), uri));
 }
 
 void ResultWatcherTest::initTestCase()
