@@ -1,23 +1,8 @@
 /*
- *   Copyright (C) 2015, 2016 Ivan Cukic <ivan.cukic(at)kde.org>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Lesser General Public
- *   License as published by the Free Software Foundation; either
- *   version 2.1 of the License, or (at your option) version 3, or any
- *   later version accepted by the membership of KDE e.V. (or its
- *   successor approved by the membership of KDE e.V.), which shall
- *   act as a proxy defined in Section 6 of version 3 of the license.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public
- *   License along with this library.
- *   If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2015, 2016 Ivan Cukic <ivan.cukic(at)kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 
 #include "resultwatcher.h"
@@ -32,6 +17,7 @@
 // Local
 #include <common/database/Database.h>
 #include <utils/debug_and_return.h>
+#include "kactivities-stats-logsettings.h"
 
 // Boost and STL
 #include <boost/range/algorithm/transform.hpp>
@@ -53,7 +39,7 @@
 
 #include <algorithm>
 
-#define QDBG qDebug() << "KActivitiesStats(" << (void*)this << ")"
+#define QDBG qCDebug(KACTIVITIES_STATS_LOG) << "KActivitiesStats(" << (void*)this << ")"
 
 namespace KActivities {
 namespace Stats {
@@ -101,7 +87,7 @@ public:
     bool activityMatches(const QString &activity) const
     {
         #if DEBUG_MATCHERS
-        qDebug() << "Activity " << activity << "matching against"
+        qCDebug(KACTIVITIES_STATS_LOG) << "Activity " << activity << "matching against"
                  << query.activities();
         #endif
 
@@ -122,7 +108,7 @@ public:
     bool agentMatches(const QString &agent) const
     {
         #if DEBUG_MATCHERS
-        qDebug() << "Agent " << agent << "matching against" << query.agents();
+        qCDebug(KACTIVITIES_STATS_LOG) << "Agent " << agent << "matching against" << query.agents();
         #endif
 
         return kamd::utils::debug_and_return(DEBUG_MATCHERS, " -> returning ",
@@ -142,7 +128,7 @@ public:
     bool urlMatches(const QString &url) const
     {
         #if DEBUG_MATCHERS
-        qDebug() << "Url " << url << "matching against" << urlFilters;
+        qCDebug(KACTIVITIES_STATS_LOG) << "Url " << url << "matching against" << urlFilters;
         #endif
 
         return kamd::utils::debug_and_return(DEBUG_MATCHERS, " -> returning ",
@@ -159,11 +145,15 @@ public:
         auto type = kamd::utils::make_lazy_val([&] () -> QString {
             using Common::Database;
 
-            auto query
+            auto database
                 = Database::instance(Database::ResourcesDatabase,
-                                     Database::ReadOnly)
-                      ->execQuery("SELECT mimetype FROM ResourceInfo WHERE "
-                                  "targettedResource = '" + resource + "'");
+                                     Database::ReadOnly);
+
+            if (!database) return QString();
+
+            auto query
+                = database->execQuery(QStringLiteral("SELECT mimetype FROM ResourceInfo WHERE "
+                                      "targettedResource = '") + resource + QStringLiteral("'"));
 
             for (const auto &item : query) {
                 return item[0].toString();
@@ -173,8 +163,8 @@ public:
         });
 
         #if DEBUG_MATCHERS
-        qDebug() << "Type " << "...type..." << "matching against" << query.types();
-        qDebug() << "ANY_TYPE_TAG" << ANY_TYPE_TAG;
+        qCDebug(KACTIVITIES_STATS_LOG) << "Type " << "...type..." << "matching against" << query.types();
+        qCDebug(KACTIVITIES_STATS_LOG) << "ANY_TYPE_TAG" << ANY_TYPE_TAG;
         #endif
 
         return kamd::utils::debug_and_return(DEBUG_MATCHERS, " -> returning ",
@@ -202,7 +192,7 @@ public:
                                     const QString &activity)
     {
         #if DEBUG_MATCHERS
-        qDebug() << "Resource has been linked: " << agent << resource << activity;
+        qCDebug(KACTIVITIES_STATS_LOG) << "Resource has been linked: " << agent << resource << activity;
         #endif
 
         // The used resources do not really care about the linked ones
@@ -220,7 +210,7 @@ public:
                                         const QString &activity)
     {
         #if DEBUG_MATCHERS
-        qDebug() << "Resource unlinked: " << agent << resource << activity;
+        qCDebug(KACTIVITIES_STATS_LOG) << "Resource unlinked: " << agent << resource << activity;
         #endif
 
         // The used resources do not really care about the linked ones
@@ -237,7 +227,7 @@ public:
                                 const QString &resource, double score,
                                 uint lastUpdate, uint firstUpdate)
     {
-        Q_ASSERT_X(activity == "00000000-0000-0000-0000-000000000000" ||
+        Q_ASSERT_X(activity == QLatin1String("00000000-0000-0000-0000-000000000000") ||
                    !QUuid(activity).isNull(),
                    "ResultWatcher::onResourceScoreUpdated",
                    "The activity should be always specified here, no magic values");
@@ -274,7 +264,7 @@ public:
         if (query.selection() == Terms::LinkedResources) return;
 
         if (activityMatches(activity) && agentMatches(agent)) {
-            if (resource.contains('*')) {
+            if (resource.contains(QLatin1Char('*'))) {
                 scheduleResultsInvalidation();
 
             } else if (typeMatches(resource)) {
@@ -376,7 +366,7 @@ void ResultWatcher::unlinkFromActivity(const QUrl &resource,
 
     for (const auto &activity : activities) {
         for (const auto &agent : agents) {
-            qDebug() << "Unlink " << agent << resource << activity;
+            qCDebug(KACTIVITIES_STATS_LOG) << "Unlink " << agent << resource << activity;
             d->linking->UnlinkResourceFromActivity(agent, resource.toString(),
                                                    activity);
         }
